@@ -32,7 +32,7 @@
 #ifndef lint
 static char copyright[] =
 "@(#) Copyright 1998 Purdue Research Foundation.\nAll rights reserved.\n";
-static char *rcsid = "$Id: usage.c,v 1.30 2011/09/07 19:13:49 abe Exp $";
+static char *rcsid = "$Id: usage.c,v 1.33 2018/02/14 14:20:14 abe Exp $";
 #endif
 
 
@@ -340,9 +340,9 @@ usage(xv, fh, version)
 
 	if (Fhelp || xv) {
 	    (void) fprintf(stderr, "%s %s\n latest revision: %s\n",
-		Pn, LSOF_VERSION, LSOF_URL);
-	    (void) fprintf(stderr, " latest FAQ: %sFAQ\n", LSOF_URL);
-	    (void) fprintf(stderr, " latest man page: %slsof_man\n", LSOF_URL);
+		Pn, LSOF_VERSION, LSOF_REPO_URL);
+	    (void) fprintf(stderr, " latest FAQ: %s\n", LSOF_FAQ_URL);
+	    (void) fprintf(stderr, " latest (non-formatted) man page: %s\n", LSOF_MAN_URL);
 	    (void) fprintf(stderr,
 		" usage: [-?ab%sh%slnNoOP%s%stUvV%s]",
 
@@ -386,18 +386,29 @@ usage(xv, fh, version)
 	    (void) fprintf(stderr, " [-A A]");
 #endif	/* defined(HAS_AFS) && defined(HASAOPT) */
 
-	    (void) fprintf(stderr, " [+|-c c] [+|-d s] [+%sD D]",
-
+	    (void) fprintf(stderr, " [+|-c c] [+|-d s] [+%sD D]%s",
 #if	defined(HASDCACHE)
-		"|-"
+		"|-",
 #else	/* !defined(HASDCACHE) */
-		""
+		"",
 #endif	/* defined(HASDCACHE) */
 
+#if	defined(HASEPTOPTS)
+		" [+|-E]"
+#else	/* !defined(HASEPTOPTS) */
+		""
+#endif	/* defined(HASEPTOPTS) */
+
 		);
 
 	    (void) fprintf(stderr,
-		" [+|-f%s%s%s%s%s%s]%s\n [-F [f]] [-g [s]] [-i [i]]",
+		" %s[+|-f%s%s%s%s%s%s]\n [-F [f]] [-g [s]] [-i [i]]",
+
+#if	defined(HASEOPT)
+		"[+|-e s] ",
+#else	/* !defined(HASEOPT) */
+		"",
+#endif	/* defined(HASEOPT) */
 
 #if	defined(HASFSTRUCT)
 		"[",
@@ -426,17 +437,11 @@ usage(xv, fh, version)
 		"n",
 # endif	/* defined(HASNOFSNADDR) */
 
-		"]",
+		"]"
 #else	/* !defined(HASFSTRUCT) */
-		"", "", "", "", "", "",
+		"", "", "", "", "", ""
 #endif	/* defined(HASFSTRUCT) */
 
-#if	defined(HASEOPT)
-		" [+|-e s]"
-#else	/* !defined(HASEOPT) */
-		""
-#endif	/* defined(HASEOPT) */
-
 		);
 
 #if	defined(HASKOPT)
@@ -464,7 +469,7 @@ usage(xv, fh, version)
 #endif	/* !defined(HASNORPC_H) */
 
 	    (void) fprintf(stderr,
-		" [-o [o]] [-p s]\n[+|-r [t]]%s [-S [t]] [-T [t]]",
+		" [-o [o]] [-p s]\n [+|-r [t]]%s [-S [t]] [-T [t]]",
 
 #if	defined(HASTCPUDPSTATE)
 		" [-s [p:s]]"
@@ -545,7 +550,8 @@ usage(xv, fh, version)
 	    col = print_in_col(col, buf);
 
 #if	defined(HASTASKS)
-	    col = print_in_col(col, "-K list tasKs");
+/* DEBUG	    col = print_in_col(col, "-K list tasKs (threads)");	*/
+	    col = print_in_col(col, "-K [i] list|(i)gn tasKs");
 #endif	/* defined(HASTASKS) */
 
 	    col = print_in_col(col, "-l list UID numbers");
@@ -601,6 +607,14 @@ usage(xv, fh, version)
 	    col = print_in_col(col, "-- end option scan");
 	    if (col != 1)
 		(void) fprintf(stderr, "\n");
+
+#if	defined(HASEPTOPTS)
+	    (void) fprintf(stderr, "  %-36.36s  %s\n",
+		"-E display endpoint info",
+		"+E display endpoint info and files"
+	    );
+#endif	/* defined(HASEPTOPTS) */
+
 	    (void) fprintf(stderr, "  %-36.36s",
 		"+f|-f  +filesystem or -file names");
 
@@ -905,11 +919,11 @@ usage(xv, fh, version)
 	 */
 	    (void) fprintf(stderr, "%s version information:\n", Pn);
 	    (void) fprintf(stderr, "    revision: %s\n", LSOF_VERSION);
-	    (void) fprintf(stderr, "    latest revision: %s\n", LSOF_URL);
-	    (void) fprintf(stderr, "    latest FAQ: %sFAQ\n",
-		LSOF_URL);
-	    (void) fprintf(stderr, "    latest man page: %slsof_man\n",
-		LSOF_URL);
+	    (void) fprintf(stderr, "    latest revision: %s\n", LSOF_REPO_URL);
+	    (void) fprintf(stderr, "    latest FAQ: %s\n",
+		LSOF_FAQ_URL);
+	    (void) fprintf(stderr, "    latest (non-formatted) man page: %s\n",
+		LSOF_MAN_URL);
 
 #if	defined(LSOF_CINFO)
 	    if ((cp = isnullstr(LSOF_CINFO)))
